<!--
<p align="center">
<img alt="zenopy logo" src="OpenRDM.png" object-fit: contain'/> 
<br>
</p>

<table align="center">
  <tr>
     <th align="left">CI/CD</th>
     <th align="left">
        <a href="https://ci.appveyor.com/project/SinaMostafanejad/openrdm"><img alt="AppVeyor" src="https://ci.appveyor.com/api/projects/status/67t0souy2fhoc7l5?svg=true"></a>
     </th>
  </tr>
  <tr>
    <th align="left">Code Coverage and Quality</th>
    <th align="left">
      <a href="https://codecov.io/gh/SinaMostafanejad/OpenRDM">
<img alt="CodeCoverage" src="https://codecov.io/gh/SinaMostafanejad/OpenRDM/branch/master/graph/badge.svg" />
      </a>
      <a href="https://lgtm.com/projects/g/SinaMostafanejad/OpenRDM/context:cpp"><img alt="Language grade: C/C++" src="https://img.shields.io/lgtm/grade/cpp/g/SinaMostafanejad/OpenRDM.svg?logo=lgtm&logoWidth=18"/></a>
<a href="https://www.codefactor.io/repository/github/sinamostafanejad/openrdm"><img src="https://www.codefactor.io/repository/github/sinamostafanejad/openrdm/badge" alt="CodeFactor" /></a>
     </th>
  </tr>
  <tr>
    <th align="left">Technical Support</th>
    <th align="left">
      <a href="https://join.slack.com/t/openrdm/shared_invite/zt-er638tpi-2MZLGxi161sQSNC7YnO8lg"><img alt="Slack Link" src="https://img.shields.io/badge/Chat on-Slack-blue?style=flat&logo=slack"></a>
    </th>
  </tr>
  <tr>
    <th align="left">Foundation</th>
    <th align="left">
      <a href="https://opensource.org/licenses/BSD-3-Clause"><img alt="GitHub license" src="https://img.shields.io/badge/license-BSD--3-blueviolet"></a>
      <a href="https://www.linuxfoundation.org/"><img alt="GitHub license" src="https://img.shields.io/badge/Platforms-Linux-blue"></a>
    </th>
  </tr>
</table>
-->

# zenopy

An open-source Python library for Zenodo REST API

## OVERVIEW

zenopy provides a comprehensive Python library for productivity
allowing scientists and engineers to publish their work on Zenodo
in compliance with FAIR principles.

## INSTALLATION

The installation procedure can be as easy as running the following
command in a terminal

```bash
pip install zenopy
```
